# ldaphelper
[![Build Status](https://travis-ci.org/christian-hawk/ldaphelper.svg?branch=master)](https://travis-ci.org/christian-hawk/ldaphelper) [![codecov](https://codecov.io/gh/christian-hawk/ldaphelper/branch/master/graph/badge.svg)](https://codecov.io/gh/christian-hawk/ldaphelper)


Wanna try to make it a little easier
